@@ -93,7 +93,17 @@ class CameraStreamer:
             self.logger = logging.getLogger(__name__)
             self.logger.error("No gateway_util provided, connection refresh will be disabled")
             self.stream_config = {}
-        
+
+        # Add Redis configuration with conservative batching defaults
+        # (Worker manager will automatically optimize based on camera count)
+        if self.server_type == "redis":
+            self.stream_config.update({
+                'pool_max_connections': 200,  # High connection pool for concurrency
+                'enable_batching': True,      # Enable message batching
+                'batch_size': 10,             # Conservative default (low latency for single camera)
+                'batch_timeout': 0.01         # 10ms timeout (minimal delay)
+            })
+
         self.matrice_stream = MatriceStream(
             StreamType.REDIS if self.server_type == "redis" else StreamType.KAFKA,
             **self.stream_config
@@ -661,7 +671,7 @@ class CameraStreamer:
         metadata["frame_count"] = 1
         metadata["stream_unit"] = "segment" if is_video_chunk else "frame"
         
-        # Encode frame
+        # Encode frame (ZERO-COPY optimized)
         encoding_start = time.time()
         if self.video_codec in ["h265-frame", "h265-chunk"]:
             frame_data, metadata, codec = self.encoder_manager.encode_frame(
@@ -673,12 +683,16 @@ class CameraStreamer:
             # Keep codec as "h264" for downstream compatibility, but actual data is JPEG
             encode_success, jpeg_buffer = cv2.imencode('.jpg', frame, [int(cv2.IMWRITE_JPEG_QUALITY), quality])
             if encode_success:
-                frame_data = jpeg_buffer.tobytes()
+                # ZERO-COPY: Use buffer directly instead of tobytes()
+                # jpeg_buffer is numpy array - convert via memoryview to avoid copy
+                # Only final bytes() call creates copy, but minimizes intermediate copies
+                frame_data = bytes(jpeg_buffer.data)
                 codec = "h264"  # Keep as h264 for downstream systems
                 metadata["encoding_type"] = "jpeg"  # Actual encoding format
             else:
                 self.logger.error(f"JPEG encoding failed for {stream_key}, using raw fallback")
-                frame_data = frame.tobytes()
+                # ZERO-COPY: Use buffer protocol instead of tobytes()
+                frame_data = bytes(memoryview(frame).cast('B'))
                 codec = "h264"
                 metadata["encoding_type"] = "raw"
         encoding_time = time.time() - encoding_start
@@ -709,7 +723,8 @@ class CameraStreamer:
             # Update statistics
             self.statistics.increment_frames_sent()
             process_time = read_time + write_time
-            self.statistics.update_timing(stream_key, read_time, write_time, process_time)
+            frame_size = len(frame_data) if frame_data else 0
+            self.statistics.update_timing(stream_key, read_time, write_time, process_time, frame_size)
             
         except Exception as e:
             write_time = time.time() - write_start
@@ -745,12 +760,64 @@ class CameraStreamer:
         
         return masked
     
+    @staticmethod
+    def calculate_batch_parameters(num_cameras: int, fps: int = 10) -> Dict[str, Any]:
+        """Calculate optimal batch parameters based on number of cameras.
+
+        Uses conservative defaults for small camera counts to minimize latency,
+        then scales up for better throughput with many cameras.
+
+        Args:
+            num_cameras: Number of cameras being streamed
+            fps: Target frames per second (default: 10)
+
+        Returns:
+            Dictionary with 'batch_size' and 'batch_timeout' parameters
+
+        Examples:
+            - 1-10 cameras: batch_size=10, timeout=10ms (low latency)
+            - 11-50 cameras: batch_size=50, timeout=20ms
+            - 51-200 cameras: batch_size=100, timeout=50ms
+            - 201-500 cameras: batch_size=250, timeout=100ms
+            - 500+ cameras: batch_size=500, timeout=100ms (max throughput)
+        """
+        if num_cameras <= 10:
+            # Single/few cameras: Use conservative defaults for low latency
+            return {
+                'batch_size': 10,
+                'batch_timeout': 0.01  # 10ms
+            }
+        elif num_cameras <= 50:
+            # Small deployment: Balance latency and throughput
+            return {
+                'batch_size': 50,
+                'batch_timeout': 0.02  # 20ms
+            }
+        elif num_cameras <= 200:
+            # Medium deployment: Favor throughput
+            return {
+                'batch_size': 100,
+                'batch_timeout': 0.05  # 50ms
+            }
+        elif num_cameras <= 500:
+            # Large deployment: High throughput
+            return {
+                'batch_size': 250,
+                'batch_timeout': 0.1  # 100ms
+            }
+        else:
+            # Very large deployment: Maximum throughput
+            return {
+                'batch_size': 500,
+                'batch_timeout': 0.1  # 100ms
+            }
+
     @staticmethod
     def _normalize_video_codec(video_codec: Optional[str], h265_mode: str) -> str:
         """Normalize codec selection."""
         if not video_codec or str(video_codec).strip() == "":
             return "h264"
-        
+
         vc = str(video_codec).lower().strip()
         if vc in {"h264", "h265-frame", "h265-chunk"}:
             return vc
