@@ -14,6 +14,7 @@ from matrice_common.session import Session
 from matrice_common.rpc import RPC
 from .streaming_gateway import StreamingGateway
 from .streaming_gateway_utils import StreamingGatewayUtil
+from .metrics_reporter import MetricsManager, MetricsConfig
 
 
 class StreamingAction:
@@ -55,7 +56,7 @@ class StreamingAction:
         session: Session,
         action_id: str,
         enable_intelligent_transmission: bool = True,
-        monitoring_interval: float = 30.0,
+        monitoring_interval: float = 30.0,  # Heartbeat sent every monitoring_interval seconds
         auto_restart: bool = True,
         max_restart_attempts: int = 3,
         action_id_check_interval: float = 60.0,
@@ -67,7 +68,7 @@ class StreamingAction:
             session: Session object for authentication
             action_id: ID of the action to manage
             enable_intelligent_transmission: Whether to enable intelligent frame transmission
-            monitoring_interval: Interval in seconds between health checks
+            monitoring_interval: Interval in seconds between health checks and heartbeats (default: 30 seconds)
             auto_restart: Whether to automatically restart on failures
             max_restart_attempts: Maximum number of restart attempts before giving up
             action_id_check_interval: Interval in seconds between checks to verify action ID matches streaming gateway
@@ -170,6 +171,9 @@ class StreamingAction:
             "last_error_time": None,
         }
 
+        # Initialize metrics manager
+        self.metrics_manager: Optional[MetricsManager] = None
+
         logging.info(
             "StreamingAction initialized successfully for gateway: %s",
             self.streaming_gateway_id,
@@ -262,6 +266,25 @@ class StreamingAction:
             if not self.streaming_gateway.start_streaming():
                 raise RuntimeError("Failed to start streaming gateway")
 
+            # Initialize metrics manager
+            try:
+                logging.info("Initializing metrics manager...")
+                metrics_config = MetricsConfig(
+                    collection_interval=1.0,  # Collect every second
+                    reporting_interval=30.0,  # Report every 30 seconds
+                )
+                self.metrics_manager = MetricsManager(
+                    streaming_gateway=self.streaming_gateway,
+                    session=self.session,
+                    streaming_gateway_id=self.streaming_gateway_id,
+                    action_id=self.action_id,
+                    config=metrics_config,
+                )
+                logging.info("Metrics manager initialized successfully")
+            except Exception as exc:
+                logging.warning(f"Failed to initialize metrics manager: {exc}", exc_info=True)
+                self.metrics_manager = None
+
             # Mark as running and start monitoring
             with self._state_lock:
                 self._is_running = True
@@ -327,6 +350,14 @@ class StreamingAction:
                 if self._monitor_thread.is_alive():
                     logging.warning("Monitor thread did not stop gracefully")
 
+            # Stop metrics manager
+            if self.metrics_manager:
+                try:
+                    logging.info("Stopping metrics manager...")
+                    self.metrics_manager.stop()
+                except Exception as exc:
+                    logging.warning(f"Error stopping metrics manager: {exc}")
+
             # Stop streaming gateway
             if self.streaming_gateway:
                 logging.info("Stopping streaming gateway...")
@@ -534,7 +565,19 @@ class StreamingAction:
                             self._restart_attempts = 0
 
                     logging.info("Sending heartbeat to streaming gateway...")
-                    self.gateway_util.send_heartbeat()
+
+                    # Gather camera configuration data
+                    camera_config = self._build_camera_config()
+
+                    # Send heartbeat with camera config
+                    self.gateway_util.send_heartbeat(camera_config=camera_config)
+
+                    # Collect and report metrics
+                    if self.metrics_manager:
+                        try:
+                            self.metrics_manager.collect_and_report()
+                        except Exception as exc:
+                            logging.warning(f"Failed to collect/report metrics: {exc}")
                 else:
                     self.stats["health_check_failures"] += 1
                     logging.warning(
@@ -581,6 +624,60 @@ class StreamingAction:
             self.stats["last_error_time"] = time.time()
             logging.error("Error recorded: %s", error_msg, exc_info=True)
 
+    def _build_camera_config(self) -> Dict:
+        """
+        Build camera configuration data for heartbeat.
+
+        Returns:
+            Dict: Camera configuration data including state and settings
+        """
+        if not self.streaming_gateway:
+            return {}
+
+        try:
+            # Get full configuration
+            config = self.streaming_gateway.get_config()
+
+            # Get runtime statistics
+            stats = self.streaming_gateway.get_statistics()
+
+            # Get camera manager stats
+            camera_manager_stats = stats.get("camera_manager_stats", {})
+
+            # Build camera config list from inputs_config
+            cameras_list = []
+            for camera in config.get("inputs_config", []):
+                camera_info = {
+                    "camera_id": camera.get("camera_id"),
+                    "camera_key": camera.get("camera_key"),
+                    "camera_group_key": camera.get("camera_group_key"),
+                    "camera_location": camera.get("camera_location"),
+                    "source": camera.get("source"),
+                    "fps": camera.get("fps"),
+                    "quality": camera.get("quality"),
+                    "width": camera.get("width"),
+                    "height": camera.get("height"),
+                    "simulate_video_file_stream": camera.get("simulate_video_file_stream", False),
+                }
+                cameras_list.append(camera_info)
+
+            # Build complete camera config payload
+            camera_config = {
+                "cameras": cameras_list,
+                "stats": {
+                    "active_cameras": camera_manager_stats.get("active_cameras", 0),
+                    "camera_ids": camera_manager_stats.get("camera_ids", []),
+                    "is_streaming": stats.get("is_streaming", False),
+                    "runtime_seconds": stats.get("runtime_seconds", 0),
+                }
+            }
+
+            return camera_config
+
+        except Exception as exc:
+            logging.warning(f"Failed to build camera config: {exc}")
+            return {}
+
     def _cleanup(self):
         """Clean up resources."""
         try:
