@@ -34,6 +34,23 @@ class StreamingGatewayUtil:
         self.server_id = server_id
         if not self.server_id and self.streaming_gateway_id:
             self.server_id = self.get_streaming_gateway_by_id().get("serverId")
+        
+        # Initialize heartbeat reporter for Kafka
+        self._heartbeat_reporter = None
+        self._init_heartbeat_reporter()
+    
+    def _init_heartbeat_reporter(self):
+        """Initialize the Kafka heartbeat reporter."""
+        try:
+            from .metrics_reporter import HeartbeatReporter
+            self._heartbeat_reporter = HeartbeatReporter(
+                self.session,
+                self.streaming_gateway_id,
+                topic="streaming_gateway_heartbeat"
+            )
+            logging.info("Heartbeat reporter initialized for streaming gateway")
+        except Exception as e:
+            logging.warning(f"Failed to initialize heartbeat reporter: {e}")
 
     def _parse_response(self, resp: dict):
         if resp.get("success"):
@@ -256,13 +273,14 @@ class StreamingGatewayUtil:
             logging.error("Status is required", exc_info=True)
             return None
 
+        # Use PUT endpoint with status in query params
         path = (
-            f"/v1/inference/update_streaming_gateway_status/{self.streaming_gateway_id}"
+            f"/v1/inference/update_streaming_gateway_status/{self.streaming_gateway_id}?status={status}"
         )
-        payload = {"status": status}
 
-        resp = self.session.rpc.put(path=path, payload=payload)
+        resp = self.session.rpc.put(path=path, payload={})
 
+        logging.info(f"Updated streaming gateway status to: {status}")
         return self._parse_response(resp)
 
     def get_and_wait_for_connection_info(
@@ -420,16 +438,31 @@ class StreamingGatewayUtil:
 
             time.sleep(1)
 
-    def send_heartbeat(self) -> Optional[Dict]:
+    def send_heartbeat(self, camera_config: Optional[Dict] = None) -> bool:
         """
-        Send a heartbeat to the streaming gateway.
+        Send a heartbeat to the streaming gateway via Kafka.
+
+        Args:
+            camera_config: Camera configuration data to include in heartbeat
+                           Should contain 'cameras' list and 'stats' dict
 
         Returns:
-            Dict: API response data or None if failed
+            bool: True if heartbeat sent successfully, False otherwise
         """
         if not self.streaming_gateway_id:
             raise ValueError("Streaming gateway ID is required")
 
-        resp = self.session.rpc.post(f"/v1/inference/add_streaming_gateway_heartbeat/{self.streaming_gateway_id}")
+        if not self._heartbeat_reporter:
+            logging.warning("Heartbeat reporter not initialized, cannot send heartbeat")
+            return False
 
-        return self._parse_response(resp)
\ No newline at end of file
+        # Use provided camera_config or empty structure
+        config = camera_config or {"cameras": [], "stats": {}}
+
+        # Send via Kafka
+        try:
+            success = self._heartbeat_reporter.send_heartbeat(config)
+            return success
+        except Exception as e:
+            logging.error(f"Failed to send heartbeat: {e}", exc_info=True)
+            return False
\ No newline at end of file
